package com.jiuqi.util.zip;

import java.io.File;
import java.io.IOException;
import java.io.InputStream;
import java.io.RandomAccessFile;
import java.io.UnsupportedEncodingException;
import java.util.Calendar;
import java.util.Date;
import java.util.Enumeration;
import java.util.Hashtable;
import java.util.zip.Inflater;
import java.util.zip.InflaterInputStream;
import java.util.zip.ZipException;

/* loaded from: com_jiuqi_util_zip.jar:com/jiuqi/util/zip/ZipFile.class */
public class ZipFile {
    private Hashtable entries;
    private Hashtable nameMap;
    private Hashtable dataOffsets;
    private String encoding;
    private RandomAccessFile archive;
    private static final int CFH_LEN = 42;
    private static final int MIN_EOCD_SIZE = 22;
    private static final int CFD_LOCATOR_OFFSET = 16;
    private static final long LFH_OFFSET_FOR_FILENAME_LENGTH = 26;

    static /* synthetic */ RandomAccessFile access$0(ZipFile zipFile) {
        return zipFile.archive;
    }

    public ZipFile(File f) throws IOException {
        this(f, (String) null);
    }

    public ZipFile(String name) throws IOException {
        this(new File(name), (String) null);
    }

    public ZipFile(String name, String encoding) throws IOException {
        this(new File(name), encoding);
    }

    public ZipFile(File f, String encoding) throws IOException {
        this.entries = new Hashtable();
        this.nameMap = new Hashtable();
        this.dataOffsets = new Hashtable();
        this.encoding = null;
        this.encoding = encoding;
        this.archive = new RandomAccessFile(f, "r");
        populateFromCentralDirectory();
        resolveLocalFileHeaderData();
    }

    public String getEncoding() {
        return this.encoding;
    }

    public void close() throws IOException {
        this.archive.close();
    }

    public Enumeration getEntries() {
        return this.entries.keys();
    }

    public ZipEntry getEntry(String name) {
        return (ZipEntry) this.nameMap.get(name);
    }

    public InputStream getInputStream(ZipEntry ze) throws IOException, ZipException {
        Long start = (Long) this.dataOffsets.get(ze);
        if (start == null) {
            return null;
        }
        BoundedInputStream bis = new BoundedInputStream(start.longValue(), ze.getCompressedSize());
        switch (ze.getMethod()) {
            case ZipOutputStream.STORED /* 0 */:
                return bis;
            case ZipOutputStream.DEFLATED /* 8 */:
                bis.addDummy();
                return new InflaterInputStream(bis, new Inflater(true));
            default:
                throw new ZipException("Found unsupported compression method " + ze.getMethod());
        }
    }

    /* JADX WARN: Incorrect condition in loop: B:3:0x01a9 */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
        To view partially-correct code enable 'Show inconsistent code' option in preferences
    */
    private void populateFromCentralDirectory() throws java.io.IOException {
        /*
            Method dump skipped, instructions count: 429
            To view this dump change 'Code comments level' option to 'DEBUG'
        */
        throw new UnsupportedOperationException("Method not decompiled: com.jiuqi.util.zip.ZipFile.populateFromCentralDirectory():void");
    }

    /* JADX WARN: Type inference failed for: r0v25, types: [java.io.RandomAccessFile] */
    private void positionAtCentralDirectory() throws IOException {
        long off = this.archive.length() - 22;
        this.archive.seek(off);
        byte[] sig = ZipOutputStream.EOCD_SIG.getBytes();
        int curr = this.archive.read();
        boolean found = false;
        while (true) {
            if (curr == -1) {
                break;
            }
            if (curr == sig[0]) {
                int curr2 = this.archive.read();
                if (curr2 == sig[1]) {
                    int curr3 = this.archive.read();
                    if (curr3 == sig[2]) {
                        int curr4 = this.archive.read();
                        if (curr4 == sig[3]) {
                            found = true;
                            break;
                        }
                    } else {
                        continue;
                    }
                } else {
                    continue;
                }
            }
            ?? r0 = this.archive;
            long j = off - 1;
            off = r0;
            r0.seek(j);
            curr = this.archive.read();
        }
        if (!found) {
            throw new ZipException("archive is not a ZIP archive");
        }
        this.archive.seek(off + 16);
        byte[] cfdOffset = new byte[4];
        this.archive.readFully(cfdOffset);
        this.archive.seek(new ZipLong(cfdOffset).getValue());
    }

    private void resolveLocalFileHeaderData() throws IOException {
        Enumeration e = getEntries();
        while (e.hasMoreElements()) {
            ZipEntry ze = (ZipEntry) e.nextElement();
            long offset = ((Long) this.entries.get(ze)).longValue();
            this.archive.seek(offset + LFH_OFFSET_FOR_FILENAME_LENGTH);
            byte[] b = new byte[2];
            this.archive.readFully(b);
            int fileNameLen = new ZipShort(b).getValue();
            this.archive.readFully(b);
            int extraFieldLen = new ZipShort(b).getValue();
            this.archive.skipBytes(fileNameLen);
            byte[] localExtraData = new byte[extraFieldLen];
            this.archive.readFully(localExtraData);
            ze.setExtra(localExtraData);
            this.dataOffsets.put(ze, new Long(offset + LFH_OFFSET_FOR_FILENAME_LENGTH + 2 + 2 + fileNameLen + extraFieldLen));
        }
    }

    protected static Date fromDosTime(ZipLong l) {
        long dosTime = l.getValue();
        Calendar cal = Calendar.getInstance();
        cal.set(1, ((int) ((dosTime >> 25) & 127)) + 1980);
        cal.set(2, ((int) ((dosTime >> 21) & 15)) - 1);
        cal.set(5, ((int) (dosTime >> 16)) & 31);
        cal.set(11, ((int) (dosTime >> 11)) & 31);
        cal.set(12, ((int) (dosTime >> 5)) & 63);
        cal.set(13, ((int) (dosTime << 1)) & 62);
        return cal.getTime();
    }

    protected String getString(byte[] bytes) throws ZipException {
        if (this.encoding == null) {
            return new String(bytes);
        }
        try {
            return new String(bytes, this.encoding);
        } catch (UnsupportedEncodingException uee) {
            throw new ZipException(uee.getMessage());
        }
    }

    /* loaded from: com_jiuqi_util_zip.jar:com/jiuqi/util/zip/ZipFile$BoundedInputStream.class */
    private class BoundedInputStream extends InputStream {
        private long remaining;
        private long loc;
        private boolean addDummyByte = false;

        /*  JADX ERROR: Failed to decode insn: 0x0005: MOVE_MULTI, method: com.jiuqi.util.zip.ZipFile.BoundedInputStream.read():int
            java.lang.ArrayIndexOutOfBoundsException: arraycopy: source index -1 out of bounds for object array[9]
            	at java.base/java.lang.System.arraycopy(Native Method)
            	at jadx.plugins.input.java.data.code.StackState.insert(StackState.java:49)
            	at jadx.plugins.input.java.data.code.CodeDecodeState.insert(CodeDecodeState.java:118)
            	at jadx.plugins.input.java.data.code.JavaInsnsRegister.dup2x1(JavaInsnsRegister.java:313)
            	at jadx.plugins.input.java.data.code.JavaInsnData.decode(JavaInsnData.java:46)
            	at jadx.core.dex.instructions.InsnDecoder.lambda$process$0(InsnDecoder.java:54)
            	at jadx.plugins.input.java.data.code.JavaCodeReader.visitInstructions(JavaCodeReader.java:81)
            	at jadx.core.dex.instructions.InsnDecoder.process(InsnDecoder.java:50)
            	at jadx.core.dex.nodes.MethodNode.load(MethodNode.java:156)
            	at jadx.core.dex.nodes.ClassNode.load(ClassNode.java:443)
            	at jadx.core.dex.nodes.ClassNode.load(ClassNode.java:449)
            	at jadx.core.ProcessClass.process(ProcessClass.java:70)
            	at jadx.core.ProcessClass.generateCode(ProcessClass.java:118)
            	at jadx.core.dex.nodes.ClassNode.generateClassCode(ClassNode.java:400)
            	at jadx.core.dex.nodes.ClassNode.decompile(ClassNode.java:388)
            	at jadx.core.dex.nodes.ClassNode.getCode(ClassNode.java:338)
            */
        /*  JADX ERROR: Failed to decode insn: 0x0036: MOVE_MULTI, method: com.jiuqi.util.zip.ZipFile.BoundedInputStream.read():int
            java.lang.ArrayIndexOutOfBoundsException: arraycopy: source index -1 out of bounds for object array[9]
            	at java.base/java.lang.System.arraycopy(Native Method)
            	at jadx.plugins.input.java.data.code.StackState.insert(StackState.java:49)
            	at jadx.plugins.input.java.data.code.CodeDecodeState.insert(CodeDecodeState.java:118)
            	at jadx.plugins.input.java.data.code.JavaInsnsRegister.dup2x1(JavaInsnsRegister.java:313)
            	at jadx.plugins.input.java.data.code.JavaInsnData.decode(JavaInsnData.java:46)
            	at jadx.core.dex.instructions.InsnDecoder.lambda$process$0(InsnDecoder.java:54)
            	at jadx.plugins.input.java.data.code.JavaCodeReader.visitInstructions(JavaCodeReader.java:81)
            	at jadx.core.dex.instructions.InsnDecoder.process(InsnDecoder.java:50)
            	at jadx.core.dex.nodes.MethodNode.load(MethodNode.java:156)
            	at jadx.core.dex.nodes.ClassNode.load(ClassNode.java:443)
            	at jadx.core.dex.nodes.ClassNode.load(ClassNode.java:449)
            	at jadx.core.ProcessClass.process(ProcessClass.java:70)
            	at jadx.core.ProcessClass.generateCode(ProcessClass.java:118)
            	at jadx.core.dex.nodes.ClassNode.generateClassCode(ClassNode.java:400)
            	at jadx.core.dex.nodes.ClassNode.decompile(ClassNode.java:388)
            	at jadx.core.dex.nodes.ClassNode.getCode(ClassNode.java:338)
            */
        @Override // java.io.InputStream
        public int read() throws java.io.IOException {
            /*
                r9 = this;
                r0 = r9
                r1 = r0
                long r1 = r1.remaining
                // decode failed: arraycopy: source index -1 out of bounds for object array[9]
                r2 = 1
                long r1 = r1 - r2
                r0.remaining = r1
                r0 = 0
                int r-1 = (r-1 > r0 ? 1 : (r-1 == r0 ? 0 : -1))
                if (r-1 > 0) goto L20
                r-1 = r9
                boolean r-1 = r-1.addDummyByte
                if (r-1 == 0) goto L1e
                r-1 = r9
                r0 = 0
                r-1.addDummyByte = r0
                r-1 = 0
                return r-1
                r-1 = -1
                return r-1
                r-1 = r9
                com.jiuqi.util.zip.ZipFile r-1 = com.jiuqi.util.zip.ZipFile.this
                com.jiuqi.util.zip.ZipFile.access$0(r-1)
                r0 = r-1
                r10 = r0
                monitor-enter(r-1)
                r-1 = r9
                com.jiuqi.util.zip.ZipFile r-1 = com.jiuqi.util.zip.ZipFile.this
                com.jiuqi.util.zip.ZipFile.access$0(r-1)
                r0 = r9
                r1 = r0
                long r1 = r1.loc
                // decode failed: arraycopy: source index -1 out of bounds for object array[9]
                r2 = 1
                long r1 = r1 + r2
                r0.loc = r1
                r-2.seek(r-1)
                r-2 = r9
                com.jiuqi.util.zip.ZipFile r-2 = com.jiuqi.util.zip.ZipFile.this
                java.io.RandomAccessFile r-2 = com.jiuqi.util.zip.ZipFile.access$0(r-2)
                int r-2 = r-2.read()
                r-1 = r10
                monitor-exit(r-1)
                return r-2
                r1 = move-exception
                monitor-exit(r1)
                throw r0
            */
            throw new UnsupportedOperationException("Method not decompiled: com.jiuqi.util.zip.ZipFile.BoundedInputStream.read():int");
        }

        BoundedInputStream(long start, long remaining) {
            this.remaining = remaining;
            this.loc = start;
        }

        /* JADX WARN: Multi-variable type inference failed */
        /* JADX WARN: Type inference failed for: r0v10, types: [java.io.RandomAccessFile] */
        /* JADX WARN: Type inference failed for: r0v11, types: [java.lang.Throwable] */
        /* JADX WARN: Type inference failed for: r0v19 */
        @Override // java.io.InputStream
        public int read(byte[] b, int off, int len) throws IOException {
            if (this.remaining <= 0) {
                if (this.addDummyByte) {
                    this.addDummyByte = false;
                    b[off] = 0;
                    return 1;
                }
                return -1;
            }
            if (len > 0) {
                if (len > this.remaining) {
                    len = (int) this.remaining;
                }
                ?? r0 = ZipFile.this.archive;
                synchronized (r0) {
                    ZipFile.this.archive.seek(this.loc);
                    int ret = ZipFile.this.archive.read(b, off, len);
                    r0 = r0;
                    if (ret > 0) {
                        this.loc += ret;
                        this.remaining -= ret;
                    }
                    return ret;
                }
            }
            return 0;
        }

        void addDummy() {
            this.addDummyByte = true;
        }
    }
}
